@@ -43,10 +43,10 @@ func StartDaemon(ctx context.Context) (*Client, error) {
 
 	env := os.Environ()
 	env = append(env, "FLY_NO_UPDATE_CHECK=1")
-	env = append(env, fmt.Sprintf("FLY_API_TOKEN=%s", config.FromContext(ctx).AccessToken))
+	env = append(env, fmt.Sprintf("FLY_API_TOKEN=%s", config.Tokens(ctx).GraphQL()))
 	cmd.Env = env
 
-	setSysProcAttributes(cmd)
+	SetSysProcAttributes(cmd)
 
 	if err := cmd.Start(); err != nil {
 		err = forkError{err}
