@@ -38,6 +38,7 @@ func (c *Client) GetAllocations(ctx context.Context, appName string, showComplet
 	req := c.NewRequest(query)
 	req.Var("appName", appName)
 	req.Var("showCompleted", showCompleted)
+	ctx = ctxWithAction(ctx, "get_allocations")
 
 	data, err := c.RunWithContext(ctx, req)
 	if err != nil {
@@ -62,6 +63,7 @@ func (c *Client) GetAllocationTaskNames(ctx context.Context, appName string) (ma
 	req := c.NewRequest(query)
 	req.Var("appName", appName)
 	req.Var("showCompleted", false)
+	ctx = ctxWithAction(ctx, "get_allocations_task_names")
 
 	data, err := c.RunWithContext(ctx, req)
 	if err != nil {
