@@ -71,6 +71,7 @@ func (client *Client) getAppsPage(ctx context.Context, orgID *string, role *stri
 		`
 
 	req := client.NewRequest(query)
+	ctx = ctxWithAction(ctx, "get_apps_page")
 	if orgID != nil {
 		req.Var("org", *orgID)
 	}
@@ -100,6 +101,7 @@ func (client *Client) GetAppID(ctx context.Context, appName string) (string, err
 
 	req := client.NewRequest(query)
 	req.Var("appName", appName)
+	ctx = ctxWithAction(ctx, "get_app_id")
 
 	data, err := client.RunWithContext(ctx, req)
 	if err != nil {
@@ -199,6 +201,7 @@ func (client *Client) GetApp(ctx context.Context, appName string) (*App, error)
 
 	req := client.NewRequest(query)
 	req.Var("appName", appName)
+	ctx = ctxWithAction(ctx, "get_app")
 
 	data, err := client.RunWithContext(ctx, req)
 	if err != nil {
@@ -237,6 +240,7 @@ func (client *Client) GetAppCompact(ctx context.Context, appName string) (*AppCo
 
 	req := client.NewRequest(query)
 	req.Var("appName", appName)
+	ctx = ctxWithAction(ctx, "get_app_compact")
 
 	data, err := client.RunWithContext(ctx, req)
 	if err != nil {
@@ -305,6 +309,7 @@ func (client *Client) GetAppInfo(ctx context.Context, appName string) (*AppInfo,
 
 	req := client.NewRequest(query)
 	req.Var("appName", appName)
+	ctx = ctxWithAction(ctx, "get_app_info")
 
 	data, err := client.RunWithContext(ctx, req)
 	if err != nil {
@@ -333,6 +338,7 @@ func (client *Client) GetAppBasic(ctx context.Context, appName string) (*AppBasi
 
 	req := client.NewRequest(query)
 	req.Var("appName", appName)
+	ctx = ctxWithAction(ctx, "get_app_basic")
 
 	data, err := client.RunWithContext(ctx, req)
 	if err != nil {
@@ -359,6 +365,7 @@ func (client *Client) GetAppMonitoring(ctx context.Context, appName string) (*Ap
 
 	req := client.NewRequest(query)
 	req.Var("appName", appName)
+	ctx = ctxWithAction(ctx, "get_app_monitoring")
 
 	data, err := client.RunWithContext(ctx, req)
 	if err != nil {
@@ -393,6 +400,7 @@ func (client *Client) GetAppPostgres(ctx context.Context, appName string) (*AppP
 
 	req := client.NewRequest(query)
 	req.Var("appName", appName)
+	ctx = ctxWithAction(ctx, "get_app_postgres")
 
 	data, err := client.RunWithContext(ctx, req)
 	if err != nil {
@@ -427,6 +435,7 @@ func (client *Client) CreateApp(ctx context.Context, input CreateAppInput) (*App
 	req := client.NewRequest(query)
 
 	req.Var("input", input)
+	ctx = ctxWithAction(ctx, "create_app")
 
 	data, err := client.RunWithContext(ctx, req)
 	if err != nil {
@@ -450,6 +459,7 @@ func (client *Client) DeleteApp(ctx context.Context, appName string) error {
 	req := client.NewRequest(query)
 
 	req.Var("appId", appName)
+	ctx = ctxWithAction(ctx, "delete_app")
 
 	_, err := client.RunWithContext(ctx, req)
 	return err
@@ -476,6 +486,7 @@ func (client *Client) MoveApp(ctx context.Context, appName string, orgID string)
 		"appId":          appName,
 		"organizationId": orgID,
 	})
+	ctx = ctxWithAction(ctx, "move_app")
 
 	data, err := client.RunWithContext(ctx, req)
 	return &data.App, err
@@ -502,6 +513,7 @@ func (client *Client) SuspendApp(ctx context.Context, appName string) (*App, err
 	req.Var("input", map[string]string{
 		"appId": appName,
 	})
+	ctx = ctxWithAction(ctx, "suspend_app")
 
 	data, err := client.RunWithContext(ctx, req)
 	return &data.SuspendApp.App, err
@@ -529,6 +541,8 @@ func (client *Client) ResumeApp(ctx context.Context, appName string) (*AppCompac
 		"appId": appName,
 	})
 
+	ctx = ctxWithAction(ctx, "resume_app")
+
 	data, err := client.RunWithContext(ctx, req)
 	return &data.ResumeApp.App, err
 }
@@ -551,6 +565,7 @@ func (client *Client) RestartApp(ctx context.Context, appName string) (*App, err
 	req.Var("input", map[string]string{
 		"appId": appName,
 	})
+	ctx = ctxWithAction(ctx, "restart_app")
 
 	data, err := client.RunWithContext(ctx, req)
 	return &data.RestartApp.App, err
@@ -574,6 +589,7 @@ func (client *Client) ResolveImageForApp(ctx context.Context, appName, imageRef
 	req := client.NewRequest(query)
 	req.Var("appName", appName)
 	req.Var("imageRef", imageRef)
+	ctx = ctxWithAction(ctx, "resolve_image")
 
 	data, err := client.RunWithContext(ctx, req)
 	if err != nil {
