@@ -20,6 +20,7 @@ func (c *Client) PlatformRegions(ctx context.Context) ([]Region, *Region, error)
 	`
 
 	req := c.NewRequest(query)
+	ctx = ctxWithAction(ctx, "platform_regions")
 
 	data, err := c.RunWithContext(ctx, req)
 	if err != nil {
@@ -57,6 +58,7 @@ func (c *Client) PlatformRegionsAll(ctx context.Context) ([]Region, error) {
 	`
 
 	req := c.NewRequest(query)
+	ctx = ctxWithAction(ctx, "platform_regions_all")
 
 	data, err := c.RunWithContext(ctx, req)
 	if err != nil {
@@ -83,6 +85,7 @@ func (c *Client) PlatformVMSizes(ctx context.Context) ([]VMSize, error) {
 	`
 
 	req := c.NewRequest(query)
+	ctx = ctxWithAction(ctx, "platform_vm_sizes")
 
 	data, err := c.RunWithContext(ctx, req)
 	if err != nil {
