@@ -9,6 +9,7 @@ func (c *Client) GetCurrentUser(ctx context.Context) (*User, error) {
 		query {
 				viewer {
 					... on User {
+						id
 						email
 						enablePaidHobby
 					}
@@ -20,6 +21,7 @@ func (c *Client) GetCurrentUser(ctx context.Context) (*User, error) {
 	`
 
 	req := c.NewRequest(query)
+	ctx = ctxWithAction(ctx, "get_current_user")
 
 	data, err := c.RunWithContext(ctx, req)
 	if err != nil {
