@@ -6,6 +6,7 @@ import (
 	"fmt"
 	"io/fs"
 	"net/http"
+	"os"
 	"path/filepath"
 	"strings"
 
@@ -19,6 +20,7 @@ import (
 	"github.com/superfly/flyctl/internal/instrument"
 	"github.com/superfly/flyctl/internal/logger"
 	"github.com/superfly/flyctl/internal/state"
+	"github.com/superfly/flyctl/internal/tracing"
 )
 
 // Preparers are split between here and `command/command.go` because
@@ -59,7 +61,7 @@ func InitClient(ctx context.Context) (context.Context, error) {
 	api.SetBaseURL(cfg.APIBaseURL)
 	api.SetErrorLog(cfg.LogGQLErrors)
 	api.SetInstrumenter(instrument.ApiAdapter)
-	api.SetTransport(httptracing.NewTransport(http.DefaultTransport))
+	api.SetTransport(tracing.NewTransport(httptracing.NewTransport(http.DefaultTransport)))
 
 	c := client.FromTokens(cfg.Tokens)
 	logger.Debug("client initialized.")
@@ -148,3 +150,19 @@ func ApplyAliases(ctx context.Context) (context.Context, error) {
 	}
 	return ctx, err
 }
+
+// This method sets the user auth token as an environment variable called FLY_OTEL_AUTH_KEY
+// Why is this necessary? It's quite difficult to get the auth token when we initialize the tracer.
+// There's no assurance it will exist at the time of creation, so we use this preparer to set it
+// And then in the tracer, we use a GRPC interceptor to pull it out when sending the traces.
+// *Another approach would be to load the config in the interceptor, and pull the tokens from it.
+// except it only came to my mind after writing this so let's stick with this for now.
+func SetOtelAuthenticationKey(ctx context.Context) (context.Context, error) {
+	token := config.Tokens(ctx).Flaps()
+	if token == "" {
+		token = os.Getenv("FLY_API_TOKEN")
+	}
+
+	os.Setenv("FLY_OTEL_AUTH_KEY", token)
+	return ctx, nil
+}
