@@ -13,7 +13,9 @@ import (
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/ctrlc"
 	"github.com/superfly/flyctl/internal/metrics"
+	"github.com/superfly/flyctl/internal/tracing"
 	"github.com/superfly/flyctl/iostreams"
+	"go.opentelemetry.io/otel/attribute"
 
 	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/flaps"
@@ -48,6 +50,8 @@ var CommonFlags = flag.Set{
 	flag.NoCache(),
 	flag.Nixpacks(),
 	flag.BuildOnly(),
+	flag.BpDockerHost(),
+	flag.BpVolume(),
 	flag.Bool{
 		Name:        "provision-extensions",
 		Description: "Provision any extensions assigned as a default to first deployments",
@@ -193,6 +197,18 @@ func run(ctx context.Context) error {
 	}
 	ctx = flaps.NewContext(ctx, flapsClient)
 
+	client := client.FromContext(ctx).API()
+
+	ctx, span := tracing.SpanFromContext(ctx, appName, "cmd.deploy")
+	defer span.End()
+
+	user, err := client.GetCurrentUser(ctx)
+	if err != nil {
+		return fmt.Errorf("failed retrieving current user: %w", err)
+	}
+
+	span.SetAttributes(attribute.String("user.id", user.ID))
+
 	appConfig, err := determineAppConfig(ctx)
 	if err != nil {
 		if strings.Contains(err.Error(), "Could not find App") {
@@ -476,10 +492,13 @@ func determineAppConfig(ctx context.Context) (cfg *appconfig.Config, err error)
 	io := iostreams.FromContext(ctx)
 	tb := render.NewTextBlock(ctx, "Verifying app config")
 	appName := appconfig.NameFromContext(ctx)
+	ctx, span := tracing.GetTracer().Start(ctx, "get_app_config")
+	defer span.End()
 
 	if cfg = appconfig.ConfigFromContext(ctx); cfg == nil {
 		cfg, err = appconfig.FromRemoteApp(ctx, appName)
 		if err != nil {
+			tracing.RecordError(span, err, "get config from remote")
 			return nil, err
 		}
 	}
@@ -487,6 +506,7 @@ func determineAppConfig(ctx context.Context) (cfg *appconfig.Config, err error)
 	if env := flag.GetStringArray(ctx, "env"); len(env) > 0 {
 		parsedEnv, err := cmdutil.ParseKVStringsToMap(env)
 		if err != nil {
+			tracing.RecordError(span, err, "parse env")
 			return nil, fmt.Errorf("failed parsing environment: %w", err)
 		}
 		cfg.SetEnvVariables(parsedEnv)
@@ -507,6 +527,7 @@ func determineAppConfig(ctx context.Context) (cfg *appconfig.Config, err error)
 		fmt.Fprintf(io.Out, extraInfo)
 	}
 	if err != nil {
+		tracing.RecordError(span, err, "validate config")
 		return nil, err
 	}
 
