@@ -5,6 +5,7 @@ import (
 
 	"github.com/spf13/cobra"
 	"github.com/superfly/flyctl/client"
+	"github.com/superfly/flyctl/flaps"
 	"github.com/superfly/flyctl/internal/appconfig"
 	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
@@ -33,25 +34,40 @@ func newPrivate() *cobra.Command {
 }
 
 func runPrivateIPAddressesList(ctx context.Context) error {
-	client := client.FromContext(ctx).API()
-
 	appName := appconfig.NameFromContext(ctx)
-	appstatus, err := client.GetAppStatus(ctx, appName, false)
+
+	apiClient := client.FromContext(ctx).API()
+	flapsClient, err := flaps.NewFromAppName(ctx, appName)
 	if err != nil {
 		return err
 	}
 
-	_, backupRegions, err := client.ListAppRegions(ctx, appName)
+	appstatus, err := apiClient.GetAppStatus(ctx, appName, false)
 	if err != nil {
 		return err
 	}
 
-	out := iostreams.FromContext(ctx).Out
-	if conf := config.FromContext(ctx); conf.JSONOutput {
-		_ = render.JSON(out, appstatus.Allocations)
-		return nil
+	switch appstatus.PlatformVersion {
+	case appconfig.NomadPlatform:
+		_, backupRegions, err := apiClient.ListAppRegions(ctx, appName)
+		if err != nil {
+			return err
+		}
+
+		out := iostreams.FromContext(ctx).Out
+		if conf := config.FromContext(ctx); conf.JSONOutput {
+			_ = render.JSON(out, appstatus.Allocations)
+			return nil
+		}
+
+		renderPrivateTable(ctx, appstatus.Allocations, backupRegions)
+	case appconfig.MachinesPlatform:
+		machines, _, err := flapsClient.ListFlyAppsMachines(ctx)
+		if err != nil {
+			return err
+		}
+		renderPrivateTableMachines(ctx, machines)
 	}
 
-	renderPrivateTable(ctx, appstatus.Allocations, backupRegions)
 	return nil
 }
