@@ -4,6 +4,7 @@ import (
 	"context"
 	"fmt"
 
+	"github.com/samber/lo"
 	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/client"
 	"github.com/superfly/flyctl/internal/appconfig"
@@ -88,6 +89,12 @@ func (state *launchState) updateConfig(ctx context.Context) {
 	} else {
 		state.appConfig.HTTPService = nil
 	}
+	state.appConfig.Compute = []*appconfig.Compute{
+		{
+			MachineGuest: state.Plan.Guest(),
+			Processes:    lo.Keys(state.appConfig.Processes),
+		},
+	}
 }
 
 // createApp creates the fly.io app for the plan
