@@ -2,10 +2,9 @@ package plan
 
 import (
 	"github.com/superfly/flyctl/api"
+	"github.com/superfly/flyctl/internal/version"
 )
 
-const descriptionNone = "<none>"
-
 type LaunchPlan struct {
 	AppName string `json:"name"`
 	OrgSlug string `json:"org"`
@@ -24,7 +23,8 @@ type LaunchPlan struct {
 
 	Redis RedisPlan `json:"redis"`
 
-	ScannerFamily string `json:"scanner_family"`
+	ScannerFamily string          `json:"scanner_family"`
+	FlyctlVersion version.Version `json:"flyctl_version"`
 }
 
 func (p *LaunchPlan) Guest() *api.MachineGuest {
