@@ -64,7 +64,7 @@ func runMachineProxy(ctx context.Context) error {
 		return err
 	}
 
-	dialer, err := agentclient.ConnectToTunnel(ctx, orgSlug)
+	dialer, err := agentclient.ConnectToTunnel(ctx, orgSlug, flag.GetBool(ctx, "quiet"))
 	if err != nil {
 		return err
 	}
