@@ -6,7 +6,6 @@ import (
 
 	"github.com/spf13/cobra"
 
-	"github.com/superfly/flyctl/api"
 	"github.com/superfly/flyctl/iostreams"
 
 	"github.com/superfly/flyctl/client"
@@ -32,8 +31,9 @@ organization later.
 	flag.Add(cmd,
 		flag.Bool{
 			Name:        "apps-v2-default-on",
-			Description: "Configure this org to use apps v2 by default for new apps",
+			Description: "Configure this org to use apps v2 by default for new apps (deprecated)",
 			Default:     false,
+			Hidden:      true,
 		},
 	)
 	cmd.Args = cobra.MaximumNArgs(1)
@@ -43,19 +43,51 @@ organization later.
 }
 
 func runCreate(ctx context.Context) error {
-	name, err := nameFromFirstArgOrPrompt(ctx)
+
+	client := client.FromContext(ctx).API()
+	io := iostreams.FromContext(ctx)
+	colorize := io.ColorScheme()
+	user, err := client.GetCurrentUser(ctx)
+
 	if err != nil {
 		return err
 	}
 
-	client := client.FromContext(ctx).API()
+	var name string
 
-	var org *api.Organization
-	if flag.GetBool(ctx, "apps-v2-default-on") {
-		org, err = client.CreateOrganizationWithAppsV2DefaultOn(ctx, name)
-	} else {
-		org, err = client.CreateOrganization(ctx, name)
+	name = flag.FirstArg(ctx)
+
+	if user.EnablePaidHobby {
+		fmt.Fprintf(io.Out, "New organizations start on the $5/mo Hobby Plan.\n\n")
+
+		if name == "" {
+			confirmed, err := prompt.Confirm(ctx, "Do you still want to create the organization?")
+
+			if err != nil {
+				return err
+			}
+
+			if !confirmed {
+				return nil
+			}
+		}
 	}
+
+	if name == "" {
+		const msg = "Enter Organization Name:"
+
+		if err = prompt.String(ctx, &name, msg, "", true); prompt.IsNonInteractive(err) {
+			err = prompt.NonInteractiveError("name argument must be specified when not running interactively")
+		}
+
+		if err != nil {
+			return err
+		}
+
+	}
+
+	org, err := client.CreateOrganization(ctx, name)
+
 	if err != nil {
 		return fmt.Errorf("failed creating organization: %w", err)
 	}
@@ -63,22 +95,9 @@ func runCreate(ctx context.Context) error {
 	if io := iostreams.FromContext(ctx); config.FromContext(ctx).JSONOutput {
 		_ = render.JSON(io.Out, org)
 	} else {
-		printOrg(io.Out, org, true)
+
+		fmt.Fprintf(io.Out, "Your organization %s (%s) was created successfully. Visit %s to add a credit card and enable deployment.\n", org.Name, org.Slug, colorize.Green(fmt.Sprintf("https://fly.io/dashboard/%s/billing", org.Slug)))
 	}
 
 	return nil
 }
-
-func nameFromFirstArgOrPrompt(ctx context.Context) (name string, err error) {
-	if name = flag.FirstArg(ctx); name != "" {
-		return
-	}
-
-	const msg = "Enter Organization Name:"
-
-	if err = prompt.String(ctx, &name, msg, "", true); prompt.IsNonInteractive(err) {
-		err = prompt.NonInteractiveError("name argument must be specified when not running interactively")
-	}
-
-	return
-}
