@@ -2,6 +2,7 @@ package redis
 
 import (
 	"context"
+	"errors"
 	"fmt"
 
 	"github.com/spf13/cobra"
@@ -18,6 +19,11 @@ import (
 	"github.com/superfly/flyctl/internal/spinner"
 )
 
+const (
+	redisPlanFree       = "x7M0gyB764ggwt6YZLRK"
+	redisPlanPayAsYouGo = "ekQ85Yjkw155ohQ5ALYq0M"
+)
+
 func newCreate() (cmd *cobra.Command) {
 	const (
 		long = `Create an Upstash Redis database`
@@ -49,10 +55,6 @@ func newCreate() (cmd *cobra.Command) {
 			Name:        "disable-eviction",
 			Description: "Disallow writes when the max data size limit has been reached",
 		},
-		flag.String{
-			Name:        "plan",
-			Description: "Upstash Redis plan",
-		},
 	)
 
 	return cmd
@@ -106,14 +108,13 @@ func runCreate(ctx context.Context) (err error) {
 			return
 		}
 	}
-	_, err = Create(ctx, org, name, primaryRegion, flag.GetString(ctx, "plan"), flag.GetBool(ctx, "no-replicas"), enableEviction, nil)
+	_, err = Create(ctx, org, name, primaryRegion, flag.GetBool(ctx, "no-replicas"), enableEviction, nil)
 	return err
 }
 
-func Create(ctx context.Context, org *api.Organization, name string, region *api.Region, planFlag string, disallowReplicas bool, enableEviction bool, readRegions *[]api.Region) (addOn *gql.AddOn, err error) {
+func Create(ctx context.Context, org *api.Organization, name string, region *api.Region, disallowReplicas bool, enableEviction bool, readRegions *[]api.Region) (addOn *gql.AddOn, err error) {
 	var (
 		io       = iostreams.FromContext(ctx)
-		client   = client.FromContext(ctx).API().GenqClient
 		colorize = io.ColorScheme()
 	)
 
@@ -148,44 +149,16 @@ func Create(ctx context.Context, org *api.Organization, name string, region *api
 		}
 	}
 
-	var planIndex int
-
-	result, err := gql.ListAddOnPlans(ctx, client)
+	plan, err := DeterminePlan(ctx, org)
 	if err != nil {
-		return
-	}
-
-	if planFlag != "" {
-		planIndex = -1
-		for index, plan := range result.AddOnPlans.Nodes {
-			if plan.DisplayName == planFlag {
-				planIndex = index
-				break
-			}
-		}
-
-		if planIndex == -1 {
-			return nil, fmt.Errorf("invalid plan name: %s", planFlag)
-		}
-	} else {
-		var planOptions []string
-
-		for _, plan := range result.AddOnPlans.Nodes {
-			planOptions = append(planOptions, fmt.Sprintf("%s: %s Max Data Size, ($%d / month)", plan.DisplayName, plan.MaxDataSize, plan.PricePerMonth))
-		}
-
-		err = prompt.Select(ctx, &planIndex, "Select an Upstash Redis plan", "", planOptions...)
-
-		if err != nil {
-			return nil, fmt.Errorf("failed to select a plan: %w", err)
-		}
+		return nil, err
 	}
 
 	s := spinner.Run(io, "Launching...")
 
 	params := RedisConfiguration{
 		Name:          name,
-		PlanId:        result.AddOnPlans.Nodes[planIndex].Id,
+		PlanId:        plan.Id,
 		PrimaryRegion: region,
 		ReadRegions:   *readRegions,
 		Eviction:      enableEviction,
@@ -198,9 +171,9 @@ func Create(ctx context.Context, org *api.Organization, name string, region *api
 		return
 	}
 
-	fmt.Fprintf(io.Out, "\nYour Upstash Redis database %s is ready.\n", colorize.Green(addOn.Name))
-	fmt.Fprintf(io.Out, "Apps in the %s org can connect to at %s\n", colorize.Green(org.Slug), colorize.Green(addOn.PublicUrl))
-	fmt.Fprintf(io.Out, "If you have redis-cli installed, use %s to connect to your database.\n", colorize.Green("fly redis connect"))
+	fmt.Fprintf(io.Out, "\nYour Upstash Redis database %s is ready. Check the pricing details at https://upstash.com/pricing.\n", colorize.Green(addOn.Name))
+	fmt.Fprintf(io.Out, "Apps in the %s org can connect to Redis at %s\n", colorize.Green(org.Slug), colorize.Green(addOn.PublicUrl))
+	fmt.Fprintf(io.Out, "If you have redis-cli installed, use %s to get a Redis console.\n", colorize.Green("fly redis connect"))
 
 	return addOn, err
 }
@@ -245,3 +218,35 @@ func ProvisionDatabase(ctx context.Context, org *api.Organization, config RedisC
 
 	return &response.CreateAddOn.AddOn, nil
 }
+
+func DeterminePlan(ctx context.Context, org *api.Organization) (*gql.ListAddOnPlansAddOnPlansAddOnPlanConnectionNodesAddOnPlan, error) {
+
+	client := client.FromContext(ctx).API()
+
+	// List redis instances
+	// If there's already a redis instance in the org, return the "Pay-as-you-go" plan
+	// Otherwise, return the "Free" plan
+
+	planId := redisPlanFree
+	listRedisResp, err := gql.ListAddOns(ctx, client.GenqClient, "redis")
+	if err != nil {
+		return nil, err
+	}
+
+	if len(listRedisResp.AddOns.Nodes) != 0 {
+		planId = redisPlanPayAsYouGo
+	}
+
+	// Now that we have the Plan ID, look up the actual plan
+	allAddons, err := gql.ListAddOnPlans(ctx, client.GenqClient)
+	if err != nil {
+		return nil, err
+	}
+
+	for _, addon := range allAddons.AddOnPlans.Nodes {
+		if addon.Id == planId {
+			return &addon, nil
+		}
+	}
+	return nil, errors.New("plan not found")
+}
