@@ -7,6 +7,7 @@ import (
 
 	"github.com/superfly/flyctl/client"
 	"github.com/superfly/flyctl/internal/appconfig"
+	"github.com/superfly/flyctl/internal/command"
 	"github.com/superfly/flyctl/internal/config"
 	"github.com/superfly/flyctl/internal/flag"
 	"github.com/superfly/flyctl/internal/render"
@@ -19,6 +20,16 @@ func runRegionsAdd(ctx context.Context) error {
 	appName := appconfig.NameFromContext(ctx)
 	apiClient := client.FromContext(ctx).API()
 
+	// regions add is not supported for machines
+	isMachine, err := command.IsMachinesPlatform(ctx, appName)
+	if err != nil {
+		return fmt.Errorf("failed to check platform version %w", err)
+	}
+
+	if isMachine {
+		return fmt.Errorf("This command is no longer supported; use fly scale count to scale the number of Machines in a region. See https://fly.io/docs/apps/scale-count/.")
+	}
+
 	input := api.ConfigureRegionsInput{
 		AppID:        appName,
 		Group:        flag.GetString(ctx, "group"),
@@ -39,6 +50,16 @@ func runRegionsRemove(ctx context.Context) error {
 	appName := appconfig.NameFromContext(ctx)
 	apiClient := client.FromContext(ctx).API()
 
+	// regions remove is not supported for machines
+	isMachine, err := command.IsMachinesPlatform(ctx, appName)
+	if err != nil {
+		return fmt.Errorf("failed to check platform version %w", err)
+	}
+
+	if isMachine {
+		return fmt.Errorf("This command is no longer supported; use fly scale count to scale the number of Machines in a region. See https://fly.io/docs/apps/scale-count/.")
+	}
+
 	input := api.ConfigureRegionsInput{
 		AppID:       appName,
 		Group:       flag.GetString(ctx, "group"),
@@ -59,6 +80,16 @@ func runRegionsSet(ctx context.Context) error {
 	appName := appconfig.NameFromContext(ctx)
 	apiClient := client.FromContext(ctx).API()
 
+	// regions set is not supported for machines
+	isMachine, err := command.IsMachinesPlatform(ctx, appName)
+	if err != nil {
+		return fmt.Errorf("failed to check platform version %w", err)
+	}
+
+	if isMachine {
+		return fmt.Errorf("This command is no longer supported; use fly scale count to scale the number of Machines in a region. See https://fly.io/docs/apps/scale-count/.")
+	}
+
 	// Get the Region List
 	regions, _, err := apiClient.ListAppRegions(ctx, appName)
 	if err != nil {
@@ -109,6 +140,16 @@ func runRegionsBackup(ctx context.Context) error {
 	appName := appconfig.NameFromContext(ctx)
 	apiClient := client.FromContext(ctx).API()
 
+	// regions backup is not supported for machines
+	isMachine, err := command.IsMachinesPlatform(ctx, appName)
+	if err != nil {
+		return fmt.Errorf("failed to check platform version %w", err)
+	}
+
+	if isMachine {
+		return fmt.Errorf("This command is no longer supported; use fly scale count to scale the number of Machines in a region. See https://fly.io/docs/apps/scale-count/.")
+	}
+
 	input := api.ConfigureRegionsInput{
 		AppID:         appName,
 		BackupRegions: flag.Args(ctx),
