@@ -6,16 +6,18 @@ package preflight
 import (
 	"strings"
 	"testing"
+	"time"
 
 	//"github.com/samber/lo"
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
+
 	//"github.com/superfly/flyctl/api"
+
 	"github.com/superfly/flyctl/test/preflight/testlib"
 )
 
 func TestFlyDeployHA(t *testing.T) {
-	t.Parallel()
-
 	f := testlib.NewTestEnvFromEnv(t)
 	appName := f.CreateRandomAppName()
 
@@ -32,7 +34,7 @@ func TestFlyDeployHA(t *testing.T) {
 	`, f.ReadFile("fly.toml"))
 
 	x := f.FlyAllowExitFailure("deploy")
-	require.Contains(f, x.StdErr().String(), `needs volumes with name 'data' to fullfill mounts defined in fly.toml`)
+	require.Contains(f, x.StdErrString(), `needs volumes with name 'data' to fullfill mounts defined in fly.toml`)
 
 	// Create two volumes because fly launch will start 2 machines because of HA setup
 	f.Fly("volume create -a %s -r %s -s 1 data -y", appName, f.PrimaryRegion())
@@ -41,18 +43,14 @@ func TestFlyDeployHA(t *testing.T) {
 }
 
 func TestFlyDeploy_DeployToken_Simple(t *testing.T) {
-	t.Parallel()
-
 	f := testlib.NewTestEnvFromEnv(t)
 	appName := f.CreateRandomAppName()
 	f.Fly("launch --org %s --name %s --region %s --image nginx --internal-port 80 --force-machines --ha=false", f.OrgSlug(), appName, f.PrimaryRegion())
-	f.OverrideAuthAccessToken(f.Fly("tokens deploy").StdOut().String())
+	f.OverrideAuthAccessToken(f.Fly("tokens deploy").StdOutString())
 	f.Fly("deploy")
 }
 
 func TestFlyDeploy_DeployToken_FailingSmokeCheck(t *testing.T) {
-	t.Parallel()
-
 	f := testlib.NewTestEnvFromEnv(t)
 	appName := f.CreateRandomAppName()
 	f.Fly("launch --org %s --name %s --region %s --image nginx --internal-port 80 --force-machines --ha=false", f.OrgSlug(), appName, f.PrimaryRegion())
@@ -62,16 +60,14 @@ func TestFlyDeploy_DeployToken_FailingSmokeCheck(t *testing.T) {
   entrypoint = "/bin/false"
 `
 	f.WriteFlyToml(appConfig)
-	f.OverrideAuthAccessToken(f.Fly("tokens deploy").StdOut().String())
+	f.OverrideAuthAccessToken(f.Fly("tokens deploy").StdOutString())
 	deployRes := f.FlyAllowExitFailure("deploy")
-	output := deployRes.StdErr().String()
+	output := deployRes.StdErrString()
 	require.Contains(f, output, "the app appears to be crashing")
 	require.NotContains(f, output, "401 Unauthorized")
 }
 
 func TestFlyDeploy_DeployToken_FailingReleaseCommand(t *testing.T) {
-	t.Parallel()
-
 	f := testlib.NewTestEnvFromEnv(t)
 	appName := f.CreateRandomAppName()
 	f.Fly("launch --org %s --name %s --region %s --image nginx --internal-port 80 --force-machines --ha=false", f.OrgSlug(), appName, f.PrimaryRegion())
@@ -83,27 +79,26 @@ func TestFlyDeploy_DeployToken_FailingReleaseCommand(t *testing.T) {
 	f.WriteFlyToml(appConfig)
 	f.OverrideAuthAccessToken(f.Fly("tokens deploy").StdOut().String())
 	deployRes := f.FlyAllowExitFailure("deploy")
-	output := deployRes.StdErr().String()
+	output := deployRes.StdErrString()
 	require.Contains(f, output, "exited with non-zero status of 1")
 	require.NotContains(f, output, "401 Unauthorized")
 }
 
 func TestFlyDeploy_Dockerfile(t *testing.T) {
-	t.Parallel()
-
 	f := testlib.NewTestEnvFromEnv(t)
 	appName := f.CreateRandomAppName()
 	f.WriteFile("Dockerfile", `FROM nginx
 ENV PREFLIGHT_TEST=true`)
 	f.Fly("launch --org %s --name %s --region %s --internal-port 80 --force-machines --ha=false --now", f.OrgSlug(), appName, f.PrimaryRegion())
-	sshResult := f.Fly("ssh console -C 'printenv PREFLIGHT_TEST'")
-	require.Equal(f, "true", strings.TrimSpace(sshResult.StdOut().String()), "expected PREFLIGHT_TEST env var to be set in machine")
+
+	require.EventuallyWithT(t, func(c *assert.CollectT) {
+		sshResult := f.Fly("ssh console -C 'printenv PREFLIGHT_TEST'")
+		assert.Equal(c, "true", strings.TrimSpace(sshResult.StdOutString()), "expected PREFLIGHT_TEST env var to be set in machine")
+	}, 30*time.Second, 2*time.Second)
 }
 
 // If this test passes at all, that means that a slow metrics server isn't affecting flyctl
 func TestFlyDeploySlowMetrics(t *testing.T) {
-	t.Parallel()
-
 	env := make(map[string]string)
 	env["FLY_METRICS_BASE_URL"] = "https://flyctl-metrics-slow.fly.dev"
 	env["FLY_SEND_METRICS"] = "1"
